<?php
/*
Plugin Name: Youtube shortcode
Plugin URI: http://wordpress.org/extend/plugins/youtube-shortcode
Description: Embed Youtube videos using shortcodes
Version: 1.1
Author: Túbal Martín
Author URI: http://margenn.com
License: GPL2

Copyright 2011  Túbal Martín  (email : tubalmartin@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


wp_enqueue_script('swfobject'); // comes bundled with wp
add_shortcode('youtube_sc','youtube_shortcode');



function youtube_shortcode( $atts, $content = null )
{
    $default_width  = '560';
    $default_height = '340';

    extract( shortcode_atts( array(
        // custom parameters
        'url' => '',
        'width' => $default_width, // minimum: 200
        'height' => $default_height,
        'version' => '2',
        'nocookie' => '0', // privacy mode
        // Youtube's official player parameters & default values
        // Reference: http://code.google.com/intl/en/apis/youtube/player_parameters.html
        'rel' => '1',
        'autoplay' => '0',
        'loop' => '0',
        'enablejsapi' => '0',
        'playerapiid' => '',
        'disablekb' => '0',
        'egm' => '0',
        'border' => '0',
        'color1' => 'b1b1b1',
        'color2' => 'cfcfcf',
        'start' => '',
        'fs' => '0',
        'hd' => '0',
        'showsearch' => '1',
        'showinfo' => '1',
        'iv_load_policy' => '1', // or 3
        'cc_load_policy' => '' // user's account setting. To force subtitles set to 1
      ), $atts ) );


   $width  = ((int) $width < 200) ? '200' : $width;
   $height = ($width != $default_width && $height == $default_height) ? (string) floor((int) $width / 1.66) : $height;

   $hl          = youtube_sc_get_hl();
   $url         = trim($url);
   $video_id    = youtube_sc_get_video_id($url);
   $video_cid   = str_replace('-', '', $video_id); // javascript safe video id
   $server_host = youtube_sc_get_server_host($url);

   $flash_or_html5_video_url = 'http://'.$server_host.'youtube.com/embed/'.$video_id.'?rel=0&amp;hl='. $hl;
   $flash_only_video_url     = 'http://'.$server_host.'youtube' . (((bool) $nocookie) ? '-nocookie' : '') . '.com/v/'.$video_id.'?version='.$version.'&amp;hl='. $hl .
       ((!(bool) $rel) ? '&amp;rel=0' : '') .
       (((bool) $autoplay) ? '&amp;autoplay=1' : '') .
       (((bool) $loop) ? '&amp;loop=1' : '') .
       (((bool) $enablejsapi) ? '&amp;enablejsapi=1' : '') .
       ((!empty($playerapiid)) ? '&amp;playerapiid=' . $playerapiid : '') .
       (((bool) $disablekb) ? '&amp;disablekb=1' : '') .
       (((bool) $egm) ? '&amp;egm=1' : '') .
       (((bool) $border) ? '&amp;border=1' : '') .
       (($color1 != 'b1b1b1') ? '&amp;color1=0x' . $color1 : '') .
       (($color2 != 'cfcfcf') ? '&amp;color2=0x' . $color2 : '') .
       ((!empty($start)) ? '&amp;start=' . $start : '') .
       (((bool) $fs) ? '&amp;fs=1' : '') .
       (((bool) $hd) ? '&amp;hd=1' : '') .
       ((!(bool) $showsearch) ? '&amp;showsearch=0' : '') .
       ((!(bool) $showinfo) ? '&amp;showinfo=0' : '') .
       (($iv_load_policy === '3') ? '&amp;iv_load_policy=' . $iv_load_policy : '') .
       ((!empty($cc_load_policy)) ? '&amp;cc_load_policy=' . $cc_load_policy : '');

   $flash_only_code = '<object width="'.$width.'" height="'.$height.'">' .
                            '<param name="movie" value="'.$flash_only_video_url.'"></param>' .
                            (((bool) $fs) ? '<param name="allowfullscreen" value="true"></param>' : '') .
                            '<param name="allowscriptaccess" value="always"></param>' .
                            '<embed src="'.$flash_only_video_url.'" type="application/x-shockwave-flash" allowscriptaccess="always" ' . (((bool) $fs) ? 'allowfullscreen="true"' : '') . 'width="'.$width.'" height="'.$height.'"></embed>' .
                      '</object>';

   return  '<div id="youtube_sc_'.$video_cid.'" class="youtube_sc" style="width:'.$width.'px; '. ((!empty($height)) ? 'height:'.$height.'px;' : '') . '">' .
               '<script type="text/javascript">' .
                   'var ytube_'.$video_cid.' = {' .
                       'flash_only: \''.$flash_only_code.'\',' .
                       'flash_or_html5: \'<iframe title="YouTube video player" class="youtube-player" type="text/html" width="'.$width.'" height="'.$height.'" src="'.$flash_or_html5_video_url.'" frameborder="0"></iframe>\'' .
                   '};' .
                   'swfobject.addDomLoadEvent(function(){document.getElementById("youtube_sc_'.$video_cid.'").innerHTML = (swfobject.ua.pv[0] > 0) ? ytube_'.$video_cid.'.flash_only : ytube_'.$video_cid.'.flash_or_html5;});' .
               '</script>' .
               '<noscript>' . $flash_only_code .'</noscript>' .
           '</div>';
}



function youtube_sc_get_video_id($url)
{
    if (preg_match('/^http\:\/\/(?:(?:[a-zA-Z0-9\-\_\.]+\.|)youtube\.com\/watch\?v\=|youtu\.be\/)([a-zA-Z0-9\-\_]+)/i', $url, $matches) > 0) {
        return $matches[1];
    }
    else if (preg_match('/^([a-zA-Z0-9\-\_]+)$/i', $url, $matches) > 0) {
        return $matches[1];
    }

    return 'QRS8MkLhQmM'; // default video ID on error
}



function youtube_sc_get_server_host($url)
{
    if (preg_match('/^http\:\/\/([a-zA-Z0-9\-\_\.]+\.|)youtube\.com/i', $url, $matches)) {
        return $matches[1];
    }

    return 'www.';
}



function youtube_sc_get_hl()
{
    $hl = 'en_US';

    if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE']) && ! empty($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
        $hl_codes = explode(',', $_SERVER['HTTP_ACCEPT_LANGUAGE']);

        if (count($hl_codes) > 0) {
            $hl_codes = explode(';', $hl_codes[0]);
            $hl_code = strtolower($hl_codes[0]);

            $hl_codes = array(
                'cs_CZ' => array('cs'), // CZECH
                'de_DE' => array('de','de-de','de-at','de-lu','de-li','de-ch'), // GERMAN
                'nl_NL' => array('nl','nl-be'), // DUTCH
                'en_GB' => array('en-gb'), // ENGLISH UK
                'es_ES' => array('es','es-es','es-ar'), // SPANISH (SPAIN & ARGENTINA)
                'es_MX' => array('es-mx','es-bo','es-cl','es-co','es-cr','es-do','es-ec','es-sv','es-gt','es-hn'), // SPANISH (MEXICO aka latin)
                'fr_FR' => array('fr','fr-fr','fr-ca','fr-be','fr-lu','fr-mc','fr-ch'), // FRENCH
                'it_IT' => array('it','it-ch'), // ITALIAN
                'ja_JP' => array('ja'), // JAPANESE
                'ko_KR' => array('ko','ko-kp','ko-kr'), // KOREAN
                'pl_PL' => array('pl'), // POLISH
                'pt_PT' => array('pt'), // PORTUGUESE
                'pt_BR' => array('pt-br'), // PORTUGUESE (BRAZIL)
                'ru_RU' => array('ru','ru-mo'), // RUSSIAN
                'sv_SE' => array('sv','sv-fi','sv-sv'), // SWEDISH
                'zh_TW' => array('zh','zh-tw','zh-hk','zh-cn','zh-sg') // CHINESE
            );

            foreach ($hl_codes as $k => $v) {
                if (in_array($hl_code, $v)) {
                    $hl = $k;
                    break;
                }
            }
        }
    }

    return $hl;
}